
// This script bundle consists of gifticonverter.js/ui and libgifticonverter_v11_bvqx21.dylib/so/dll, place in /Documents/BVQXExtensions/Plugins_xx/ folder.
// Functionality: Converts surface files between BrainVoyager and GIFTI.
// Usage: In the BrainVoyager menu, select 'Plugins' > GIFTI converter v1.4.
// Latest update: 20-09-2018
// Joost Mulders and Hester Breman, 2008-2018.

var scriptObj 					= new Object; 
scriptObj.scriptNameForUser 	= "GIFTI converter"; 
scriptObj.dialogFileName 		= "gifticonverter_v16.ui"; 
scriptObj.dialogAccessName      = "giftiDlg"; 
BrainVoyager.PrintToLog("Script started...");

var command = "Unknown";
const FILE_TYPE_GIFTI   = 1;
const FILE_TYPE_SRF     = 2;
const FILE_TYPE_MTC     = 3;
const FILE_TYPE_SMP     = 4;
const FILE_TYPE_POI     = 5;
const FILE_TYPE_UNKNOWN = 99;

// main menu
var startImportButton, startExportButton, startPrintButton;
// import menu
var doPrintImportBox, doShowImportBox, doReverseBox,doAddColorsBox;
var gii2srfButton, gii2mtcButton, gii2smpButton, gii2poiButton;
// export menu
var srf2giiButton, mtc2giiButton, smp2giiButton, poi2giiButton;
var exportCurrOpenBox, export2BinaryBox, exportColorsBox;
// print menu
var printCurrentOpenBox, printToFileBox, printToLogBox;
var printgiiBox, printsrfBox, printmtcBox, printsmpBox, printpoiBox;

scriptObj.getImportFiletype = function() {

    var filetypeid;
    if (gii2srfButton.checked == 1) {
        filetypeid = FILE_TYPE_SRF; 
    } else if (gii2mtcButton.checked == 1) {
        filetypeid = FILE_TYPE_MTC;
    } else if (gii2smpButton.checked == 1) {
        filetypeid = FILE_TYPE_SMP;
    } else if (gii2poiButton.checked == 1) {
        filetypeid = FILE_TYPE_POI;
    }
    return filetypeid;
}

scriptObj.getExportFiletype = function() {

    var filetypeid;
    if (srf2giiButton.checked == 1) {
        filetypeid = FILE_TYPE_SRF; 
    } else if (mtc2giiButton.checked == 1) {
        filetypeid = FILE_TYPE_MTC;
    } else if (smp2giiButton.checked == 1) {
        filetypeid = FILE_TYPE_SMP;
    } else if (poi2giiButton.checked == 1) {
        filetypeid = FILE_TYPE_POI;
    } else {
        filetypeid = FILE_TYPE_UNKNOWN;
    }
    return filetypeid;
}

scriptObj.GetExportStartPoint = function() {

    if (exportCurrOpenBox.checked == 1) return 1;
    else return 0;

}

scriptObj.getPrintFiletype = function() {

    var filetypeid;
    if (printgiiBox.checked == 1) {
        filetypeid = FILE_TYPE_GIFTI;
    } else if (printsrfBox.checked == 1) {
        filetypeid = FILE_TYPE_SRF; 
    } else if (printmtcBox.checked == 1) {
        filetypeid = FILE_TYPE_MTC;
    } else if (printsmpBox.checked == 1) {
        filetypeid = FILE_TYPE_SMP;
    } else if (printpoiBox.checked == 1) {
        filetypeid = FILE_TYPE_POI;
    } 
    return filetypeid;
}

scriptObj.startImport = function() {

    var doPrint = doPrintImportBox.checked;// vraag hier de waarde van chboxPrint uit
    var doShow = doShowImportBox.checked;// vraag hier de waarde van chboxShow uit
    var doReverse = doReverseBox.checked;
    var addColorsFile = doAddColorsBox.checked;
    var filetypeid = this.getImportFiletype();
      
    BrainVoyager.SetPluginStringParameter("Command", "Import"); 
    BrainVoyager.SetPluginIntParameter("FileTypeId", filetypeid);
    BrainVoyager.SetPluginIntParameter("PrintToLogtab", doPrint);
    BrainVoyager.SetPluginIntParameter("OpenInBVQX", doShow);
    BrainVoyager.SetPluginIntParameter("ReverseWinding", doReverse);
    BrainVoyager.SetPluginIntParameter("AddColorsFile", addColorsFile);  
    this.giftiDlg.close(); // 01-02-11  
    BrainVoyager.ExecutePlugin(); 

    // ask parameters from plugin
    // if succeeded, open in BrainVoyager (if checked && if surface (MTC and SMP are loaded from plugin functions))
    if ((filetypeid == FILE_TYPE_SRF) && (doShow)) {
        // get filename from plugin
        var srffilename = BrainVoyager.GetPluginStringParameter("SrfFileName"); 
        BrainVoyager.PrintToLog("Name of imported surface file: '" + srffilename + "'"); 
        // load mesh
        var vmrdoc = BrainVoyager.ActiveDocument;
        vmrdoc.LoadMesh(srffilename);
    }

    //this.giftiDlg.close();
}

scriptObj.startExport = function() {

    var doBinExp = export2BinaryBox.checked;
    var useCurrentFile = this.GetExportStartPoint();
    var filetypeid = this.getExportFiletype();
    var exportColors = exportColorsBox.checked;
    BrainVoyager.SetPluginStringParameter("Command", "Export"); 
    BrainVoyager.SetPluginIntParameter("FileTypeId", filetypeid);
    BrainVoyager.SetPluginIntParameter("DoBinaryExport", doBinExp);
    BrainVoyager.SetPluginIntParameter("UseCurrentFile", useCurrentFile);
    BrainVoyager.SetPluginIntParameter("DoExportColors", exportColors);
    this.giftiDlg.close();
    BrainVoyager.ExecutePlugin(); 
}

scriptObj.startPrint = function() {

    BrainVoyager.PrintToLog("Starting print...");

    var doPrintToLog = printToLogBox.checked;
    var doPrintToFile = printToFileBox.checked;
    var useCurrentFile = printCurrentOpenBox.checked;
    var filetypeid = this.getPrintFiletype();
      
    BrainVoyager.SetPluginStringParameter("Command", "Print"); 
    BrainVoyager.SetPluginIntParameter("FileTypeId", filetypeid);
    BrainVoyager.SetPluginIntParameter("PrintToLog", doPrintToLog);
    BrainVoyager.SetPluginIntParameter("PrintToFile", doPrintToFile);
    BrainVoyager.SetPluginIntParameter("UseCurrentFile", useCurrentFile);
    this.giftiDlg.close();
    BrainVoyager.ExecutePlugin(); 
}


scriptObj.changePrintDestinationState = function() {
	
	BrainVoyager.PrintToLog("Script> Change checkbox state…"); 
    var tolog = printToLogBox.enabled;
    var tofile = printToFileBox.enabled;
    
	if ((!tolog) && (!tofile)) {
        printToLogBox.enabled = true;
    }
}


scriptObj.initDlg = function() { 

    this.giftiDlg.windowTitle = "GIFTI converter"; 
    
    // ~~~ find all children ~~~
    // main menu children
    startImportButton = BrainVoyager.FindChild("btnStartImport"); 
    startExportButton = BrainVoyager.FindChild("btnStartExport"); 
    startPrintButton = BrainVoyager.FindChild("btnStartPrint");
    // import children
    gii2srfButton = BrainVoyager.FindChild("rbtnGII2SRF");
    gii2mtcButton = BrainVoyager.FindChild("rbtnGII2MTC");
    gii2smpButton = BrainVoyager.FindChild("rbtnGII2SMP");
    gii2poiButton = BrainVoyager.FindChild("rbtnGII2POI");
    
    doPrintImportBox = BrainVoyager.FindChild("chboxPrint");
    doShowImportBox = BrainVoyager.FindChild("chboxShow");
    doReverseBox = BrainVoyager.FindChild("chboxReverse");
    doAddColorsBox = BrainVoyager.FindChild("chboxAddColors");
    
    //export Children
    srf2giiButton = BrainVoyager.FindChild("rbtnSRF2GII");
    mtc2giiButton = BrainVoyager.FindChild("rbtnMTC2GII");
    smp2giiButton = BrainVoyager.FindChild("rbtnSMP2GII");
    poi2giiButton = BrainVoyager.FindChild("rbtnPOI2GII");
    exportCurrOpenBox = BrainVoyager.FindChild("rbtnCurrOpen");
    export2BinaryBox = BrainVoyager.FindChild("chboxBinData");
    exportColorsBox = BrainVoyager.FindChild("chboxExportColors");
    
    // print children
    printgiiBox = BrainVoyager.FindChild("rbtnPrntGII"); 
    printsrfBox = BrainVoyager.FindChild("rbtnPrntSRF");
    printmtcBox = BrainVoyager.FindChild("rbtnPrntMTC");
    printsmpBox = BrainVoyager.FindChild("rbtnPrntSMP"); 
    printpoiBox = BrainVoyager.FindChild("rbtnPrntPOI");
    printToFileBox = BrainVoyager.FindChild("chboxPrnt2File"); 
    printToLogBox = BrainVoyager.FindChild("chboxPrnt2Log");
    printCurrentOpenBox = BrainVoyager.FindChild("chboxPrintCurrOpen");    

    // connect all the widgets to functions here
    startImportButton.clicked.connect(this, this.startImport);
    startExportButton.clicked.connect(this, this.startExport);
    startPrintButton.clicked.connect(this, this.startPrint); 
   
    // dynamic setting of print destination
    printToFileBox.connect(this, this.changePrintDestinationState);
    printToLogBox.connect(this, this.changePrintDestinationState);
    
}

returnScriptObj = function() { 
	return scriptObj; 
} 

returnScriptObj(); 
